@@ -53,6 +53,7 @@ create table `t_flink_app` (
   `jar` varchar(255) collate utf8mb4_general_ci default null,
   `jar_check_sum` bigint default null,
   `main_class` varchar(255) collate utf8mb4_general_ci default null,
+  `dependency` text collate utf8mb4_general_ci default null,
   `args` text collate utf8mb4_general_ci,
   `options` text collate utf8mb4_general_ci,
   `hot_params` text collate utf8mb4_general_ci,
@@ -86,7 +87,7 @@ create table `t_flink_app` (
   `option_state` tinyint default null,
   `tracking` tinyint default null,
   `create_time` datetime not null default current_timestamp comment 'create time',
-  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+  `modify_time` datetime not null default current_timestamp comment 'modify time',
   `option_time` datetime default null,
   `release` tinyint default 1,
   `build` tinyint default 1,
