@@ -17,7 +17,9 @@
 
 package org.apache.streampark.console.core.controller;
 
+import io.swagger.v3.oas.annotations.Hidden;
 import org.springframework.stereotype.Controller;
+import org.springframework.web.bind.annotation.GetMapping;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.servlet.ModelAndView;
 
@@ -25,7 +27,8 @@ import org.springframework.web.servlet.ModelAndView;
 @Controller
 public class IndexController {
 
-  @RequestMapping("/")
+  @Hidden
+  @GetMapping("/")
   public ModelAndView index() {
     return new ModelAndView("/index.html");
   }
