@@ -26,20 +26,16 @@ import org.apache.streampark.common.enums.ExecutionMode;
 import org.apache.streampark.common.enums.FlinkK8sRestExposedType;
 import org.apache.streampark.common.enums.StorageType;
 import org.apache.streampark.common.fs.FsOperator;
-import org.apache.streampark.common.util.FileUtils;
-import org.apache.streampark.common.util.Utils;
 import org.apache.streampark.console.base.util.JacksonUtils;
-import org.apache.streampark.console.base.util.ObjectUtils;
-import org.apache.streampark.console.base.util.WebUtils;
 import org.apache.streampark.console.core.bean.AppControl;
+import org.apache.streampark.console.core.bean.MavenDependency;
 import org.apache.streampark.console.core.enums.FlinkAppState;
 import org.apache.streampark.console.core.enums.ReleaseState;
 import org.apache.streampark.console.core.enums.ResourceFrom;
 import org.apache.streampark.console.core.metrics.flink.JobsOverview;
 import org.apache.streampark.console.core.utils.YarnQueueLabelExpression;
 import org.apache.streampark.flink.kubernetes.model.K8sPodTemplates;
-import org.apache.streampark.flink.packer.maven.Artifact;
-import org.apache.streampark.flink.packer.maven.DependencyInfo;
+import org.apache.streampark.flink.packer.maven.MavenArtifact;
 
 import org.apache.commons.lang3.StringUtils;
 
@@ -49,24 +45,19 @@ import com.baomidou.mybatisplus.annotation.TableField;
 import com.baomidou.mybatisplus.annotation.TableId;
 import com.baomidou.mybatisplus.annotation.TableName;
 import com.fasterxml.jackson.annotation.JsonIgnore;
-import com.fasterxml.jackson.core.type.TypeReference;
 import lombok.Data;
 import lombok.SneakyThrows;
 import lombok.extern.slf4j.Slf4j;
 
 import javax.annotation.Nonnull;
 
-import java.io.File;
 import java.io.Serializable;
 import java.util.Collections;
 import java.util.Date;
 import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
-import java.util.stream.Collectors;
 
 import static org.apache.streampark.console.core.enums.FlinkAppState.of;
 
@@ -160,6 +151,9 @@ public class Application implements Serializable {
 
   private String mainClass;
 
+  @TableField(updateStrategy = FieldStrategy.IGNORED)
+  private String dependency;
+
   private Date startTime;
 
   @TableField(updateStrategy = FieldStrategy.IGNORED)
@@ -220,7 +214,6 @@ public class Application implements Serializable {
   /** running job */
   private transient JobsOverview.Task overview;
 
-  private transient String dependency;
   private transient Long sqlId;
   private transient String flinkSql;
 
@@ -390,35 +383,26 @@ public class Application implements Serializable {
         && this.cpFailureAction != null;
   }
 
-  public boolean eqFlinkJob(Application other) {
-    if (this.isFlinkSqlJob() && other.isFlinkSqlJob()) {
-      if (this.getFlinkSql().trim().equals(other.getFlinkSql().trim())) {
-        return this.getDependencyObject().eq(other.getDependencyObject());
-      }
-    }
-    return false;
-  }
-
   /** Local compilation and packaging working directory */
   @JsonIgnore
   public String getDistHome() {
     String path =
         String.format("%s/%s/%s", Workspace.APP_LOCAL_DIST(), projectId.toString(), getModule());
-    log.info("local distHome:{}", path);
+    log.info("local distHome: {}", path);
     return path;
   }
 
   @JsonIgnore
   public String getLocalAppHome() {
     String path = String.format("%s/%s", Workspace.local().APP_WORKSPACE(), id.toString());
-    log.info("local appHome:{}", path);
+    log.info("local appHome: {}", path);
     return path;
   }
 
   @JsonIgnore
   public String getRemoteAppHome() {
     String path = String.format("%s/%s", Workspace.remote().APP_WORKSPACE(), id.toString());
-    log.info("remote appHome:{}", path);
+    log.info("remote appHome: {}", path);
     return path;
   }
 
@@ -446,6 +430,11 @@ public class Application implements Serializable {
     return getAppHome().concat("/lib");
   }
 
+  @JsonIgnore
+  public String getLocalAppLib() {
+    return getLocalAppHome().concat("/lib");
+  }
+
   @JsonIgnore
   public ApplicationType getApplicationType() {
     return ApplicationType.of(appType);
@@ -473,6 +462,12 @@ public class Application implements Serializable {
     return DevelopmentMode.CUSTOM_CODE.getValue().equals(this.getJobType());
   }
 
+  @JsonIgnore
+  public boolean isApacheFlinkCustomCodeJob() {
+    return DevelopmentMode.CUSTOM_CODE.getValue().equals(this.getJobType())
+        && getApplicationType() == ApplicationType.APACHE_FLINK;
+  }
+
   @JsonIgnore
   public boolean isUploadJob() {
     return isCustomCodeJob() && ResourceFrom.UPLOAD.getValue().equals(this.getResourceFrom());
@@ -489,13 +484,13 @@ public class Application implements Serializable {
 
   @JsonIgnore
   @SneakyThrows
-  public Dependency getDependencyObject() {
-    return Dependency.toDependency(this.dependency);
+  public MavenDependency getMavenDependency() {
+    return MavenDependency.of(this.dependency);
   }
 
   @JsonIgnore
-  public DependencyInfo getDependencyInfo() {
-    return Application.Dependency.toDependency(getDependency()).toJarPackDeps();
+  public MavenArtifact getMavenArtifact() {
+    return getMavenDependency().toMavenArtifact();
   }
 
   @JsonIgnore
@@ -516,75 +511,6 @@ public class Application implements Serializable {
     return false;
   }
 
-  /**
-   * Parameter comparison, mainly to compare whether the parameters related to Flink runtime have
-   * changed
-   */
-  public boolean eqJobParam(Application other) {
-    // 1) Resolve Order has it changed
-    // 2) flink Version has it changed
-    // 3) Execution Mode has it changed
-    // 4) Parallelism has it changed
-    // 5) Task Slots has it changed
-    // 6) Options has it changed
-    // 7) properties has it changed
-    // 8) Program Args has it changed
-    // 9) Flink Version  has it changed
-
-    if (!ObjectUtils.safeEquals(this.getVersionId(), other.getVersionId())) {
-      return false;
-    }
-
-    if (!ObjectUtils.safeEquals(this.getResolveOrder(), other.getResolveOrder())
-        || !ObjectUtils.safeEquals(this.getExecutionMode(), other.getExecutionMode())
-        || !ObjectUtils.safeEquals(this.getK8sRestExposedType(), other.getK8sRestExposedType())) {
-      return false;
-    }
-
-    if (this.getOptions() != null) {
-      if (other.getOptions() != null) {
-        if (!this.getOptions().trim().equals(other.getOptions().trim())) {
-          Map<String, Object> optMap = this.getOptionMap();
-          Map<String, Object> otherMap = other.getOptionMap();
-          if (optMap.size() != otherMap.size()) {
-            return false;
-          }
-          for (Map.Entry<String, Object> entry : optMap.entrySet()) {
-            if (!entry.getValue().equals(otherMap.get(entry.getKey()))) {
-              return false;
-            }
-          }
-        }
-      } else {
-        return false;
-      }
-    } else if (other.getOptions() != null) {
-      return false;
-    }
-
-    if (this.getDynamicProperties() != null) {
-      if (other.getDynamicProperties() != null) {
-        if (!this.getDynamicProperties().trim().equals(other.getDynamicProperties().trim())) {
-          return false;
-        }
-      } else {
-        return false;
-      }
-    } else if (other.getDynamicProperties() != null) {
-      return false;
-    }
-
-    if (this.getArgs() != null) {
-      if (other.getArgs() != null) {
-        return this.getArgs().trim().equals(other.getArgs().trim());
-      } else {
-        return false;
-      }
-    } else {
-      return other.getArgs() == null;
-    }
-  }
-
   @JsonIgnore
   public StorageType getStorageType() {
     return getStorageType(getExecutionMode());
@@ -652,65 +578,6 @@ public class Application implements Serializable {
     return ExecutionMode.YARN_PER_JOB.equals(mode) || ExecutionMode.YARN_APPLICATION.equals(mode);
   }
 
-  @Data
-  public static class Dependency {
-    private List<Pom> pom = Collections.emptyList();
-    private List<String> jar = Collections.emptyList();
-
-    @SneakyThrows
-    public static Dependency toDependency(String dependency) {
-      if (Utils.notEmpty(dependency)) {
-        return JacksonUtils.read(dependency, new TypeReference<Dependency>() {});
-      }
-      return new Dependency();
-    }
-
-    public boolean isEmpty() {
-      return pom.isEmpty() && jar.isEmpty();
-    }
-
-    public boolean eq(Dependency other) {
-      if (other == null) {
-        return false;
-      }
-      if (this.isEmpty() && other.isEmpty()) {
-        return true;
-      }
-
-      if (this.pom.size() != other.pom.size() || this.jar.size() != other.jar.size()) {
-        return false;
-      }
-      File localJar = WebUtils.getAppTempDir();
-      File localUploads = new File(Workspace.local().APP_UPLOADS());
-      HashSet<String> otherJars = new HashSet<>(other.jar);
-      for (String jarName : jar) {
-        if (!otherJars.contains(jarName)
-            || !FileUtils.equals(new File(localJar, jarName), new File(localUploads, jarName))) {
-          return false;
-        }
-      }
-      return new HashSet<>(pom).containsAll(other.pom);
-    }
-
-    public DependencyInfo toJarPackDeps() {
-      List<Artifact> mvnArts =
-          this.pom.stream()
-              .map(
-                  pom ->
-                      new Artifact(
-                          pom.getGroupId(),
-                          pom.getArtifactId(),
-                          pom.getVersion(),
-                          pom.getClassifier()))
-              .collect(Collectors.toList());
-      List<String> extJars =
-          this.jar.stream()
-              .map(jar -> Workspace.local().APP_UPLOADS() + "/" + jar)
-              .collect(Collectors.toList());
-      return new DependencyInfo(mvnArts, extJars);
-    }
-  }
-
   @Override
   public boolean equals(Object o) {
     if (this == o) {
@@ -726,37 +593,4 @@ public class Application implements Serializable {
   public int hashCode() {
     return Objects.hash(id);
   }
-
-  @Data
-  public static class Pom {
-    private String groupId;
-    private String artifactId;
-    private String version;
-    private String classifier;
-
-    @Override
-    public boolean equals(Object o) {
-      if (this == o) {
-        return true;
-      }
-      if (o == null || getClass() != o.getClass()) {
-        return false;
-      }
-      return this.toString().equals(o.toString());
-    }
-
-    @Override
-    public int hashCode() {
-      return Objects.hash(groupId, artifactId, version, classifier);
-    }
-
-    @Override
-    public String toString() {
-      return groupId + ":" + artifactId + ":" + version + getClassifier(":");
-    }
-
-    private String getClassifier(String joiner) {
-      return StringUtils.isEmpty(classifier) ? "" : joiner + classifier;
-    }
-  }
 }
