@@ -20,7 +20,6 @@ package org.apache.streampark.console.core.service.impl;
 import org.apache.streampark.common.conf.ConfigConst;
 import org.apache.streampark.common.conf.Workspace;
 import org.apache.streampark.common.enums.ApplicationType;
-import org.apache.streampark.common.enums.DevelopmentMode;
 import org.apache.streampark.common.enums.ExecutionMode;
 import org.apache.streampark.common.fs.FsOperator;
 import org.apache.streampark.common.util.FileUtils;
@@ -39,6 +38,7 @@ import org.apache.streampark.console.core.enums.CandidateType;
 import org.apache.streampark.console.core.enums.NoticeType;
 import org.apache.streampark.console.core.enums.OptionState;
 import org.apache.streampark.console.core.enums.ReleaseState;
+import org.apache.streampark.console.core.enums.ResourceFrom;
 import org.apache.streampark.console.core.mapper.ApplicationBuildPipelineMapper;
 import org.apache.streampark.console.core.service.AppBuildPipeService;
 import org.apache.streampark.console.core.service.ApplicationBackUpService;
@@ -52,6 +52,8 @@ import org.apache.streampark.console.core.service.MessageService;
 import org.apache.streampark.console.core.service.SettingService;
 import org.apache.streampark.console.core.task.FlinkRESTAPIWatcher;
 import org.apache.streampark.flink.packer.docker.DockerConf;
+import org.apache.streampark.flink.packer.maven.Artifact;
+import org.apache.streampark.flink.packer.maven.MavenTool;
 import org.apache.streampark.flink.packer.pipeline.BuildPipeline;
 import org.apache.streampark.flink.packer.pipeline.BuildResult;
 import org.apache.streampark.flink.packer.pipeline.DockerBuildSnapshot;
@@ -72,6 +74,7 @@ import org.apache.streampark.flink.packer.pipeline.impl.FlinkK8sSessionBuildPipe
 import org.apache.streampark.flink.packer.pipeline.impl.FlinkRemoteBuildPipeline;
 import org.apache.streampark.flink.packer.pipeline.impl.FlinkYarnApplicationBuildPipeline;
 
+import org.apache.commons.codec.digest.DigestUtils;
 import org.apache.commons.collections.CollectionUtils;
 
 import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
@@ -87,10 +90,15 @@ import org.springframework.transaction.annotation.Transactional;
 import javax.annotation.Nonnull;
 
 import java.io.File;
+import java.io.IOException;
+import java.io.InputStream;
+import java.nio.file.Files;
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
+import java.util.Set;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.ThreadPoolExecutor;
@@ -164,7 +172,7 @@ public class AppBuildPipeServiceImpl
     pipeline.registerWatcher(
         new PipeWatcher() {
           @Override
-          public void onStart(PipeSnapshot snapshot) {
+          public void onStart(PipeSnapshot snapshot) throws Exception {
             AppBuildPipeline buildPipeline =
                 AppBuildPipeline.fromPipeSnapshot(snapshot).setAppId(app.getId());
             saveEntity(buildPipeline);
@@ -180,52 +188,7 @@ public class AppBuildPipeServiceImpl
             applicationService.checkEnv(app);
 
             // 2) some preparatory work
-            String appUploads = app.getWorkspace().APP_UPLOADS();
-
-            if (app.isCustomCodeJob()) {
-              // customCode upload jar to appHome...
-              String appHome = app.getAppHome();
-              FsOperator fsOperator = app.getFsOperator();
-              fsOperator.delete(appHome);
-              if (app.isUploadJob()) {
-                File localJar = new File(WebUtils.getAppTempDir(), app.getJar());
-                // upload jar copy to appHome
-                String uploadJar = appUploads.concat("/").concat(app.getJar());
-                checkOrElseUploadJar(app.getFsOperator(), localJar, uploadJar, appUploads);
-                switch (app.getApplicationType()) {
-                  case STREAMPARK_FLINK:
-                    fsOperator.mkdirs(app.getAppLib());
-                    fsOperator.copy(uploadJar, app.getAppLib(), false, true);
-                    break;
-                  case APACHE_FLINK:
-                    fsOperator.mkdirs(appHome);
-                    fsOperator.copy(uploadJar, appHome, false, true);
-                    break;
-                  default:
-                    throw new IllegalArgumentException(
-                        "[StreamPark] unsupported ApplicationType of custom code: "
-                            + app.getApplicationType());
-                }
-              } else {
-                fsOperator.upload(app.getDistHome(), appHome);
-              }
-            } else {
-              if (!app.getDependencyObject().getJar().isEmpty()) {
-                String localUploads = Workspace.local().APP_UPLOADS();
-                // copy jar to local upload dir
-                for (String jar : app.getDependencyObject().getJar()) {
-                  File localJar = new File(WebUtils.getAppTempDir(), jar);
-                  File uploadJar = new File(localUploads, jar);
-                  if (!localJar.exists() && !uploadJar.exists()) {
-                    throw new ApiAlertException("Missing file: " + jar + ", please upload again");
-                  }
-                  if (localJar.exists()) {
-                    checkOrElseUploadJar(
-                        FsOperator.lfs(), localJar, uploadJar.getAbsolutePath(), localUploads);
-                  }
-                }
-              }
-            }
+            prepareJars(app);
           }
 
           @Override
@@ -333,26 +296,20 @@ public class AppBuildPipeServiceImpl
   /** create building pipeline instance */
   private BuildPipeline createPipelineInstance(@Nonnull Application app) {
     FlinkEnv flinkEnv = flinkEnvService.getByIdOrDefault(app.getVersionId());
-    String flinkUserJar = retrieveFlinkUserJar(flinkEnv, app);
+    String userLocalJar = retrieveUserLocalJar(flinkEnv, app);
     ExecutionMode executionMode = app.getExecutionModeEnum();
-    String mainClass = ConfigConst.STREAMPARK_FLINKSQL_CLIENT_CLASS();
+    String mainClass =
+        app.isCustomCodeJob() ? app.getMainClass() : ConfigConst.STREAMPARK_FLINKSQL_CLIENT_CLASS();
     switch (executionMode) {
       case YARN_APPLICATION:
         String yarnProvidedPath = app.getAppLib();
-        String localWorkspace = app.getLocalAppHome().concat("/lib");
-        if (app.getDevelopmentMode().equals(DevelopmentMode.CUSTOM_CODE)
-            && app.getApplicationType().equals(ApplicationType.APACHE_FLINK)) {
-          yarnProvidedPath = app.getAppHome();
-          localWorkspace = app.getLocalAppHome();
-        }
         FlinkYarnApplicationBuildRequest yarnAppRequest =
             new FlinkYarnApplicationBuildRequest(
                 app.getJobName(),
                 mainClass,
-                localWorkspace,
                 yarnProvidedPath,
                 app.getDevelopmentMode(),
-                app.getDependencyInfo());
+                app.getMavenArtifact());
         log.info("Submit params to building pipeline : {}", yarnAppRequest);
         return FlinkYarnApplicationBuildPipeline.of(yarnAppRequest);
       case YARN_PER_JOB:
@@ -363,12 +320,11 @@ public class AppBuildPipeServiceImpl
                 app.getJobName(),
                 app.getLocalAppHome(),
                 mainClass,
-                flinkUserJar,
-                app.isCustomCodeJob(),
+                userLocalJar,
                 app.getExecutionModeEnum(),
                 app.getDevelopmentMode(),
                 flinkEnv.getFlinkVersion(),
-                app.getDependencyInfo());
+                app.getMavenArtifact());
         log.info("Submit params to building pipeline : {}", buildRequest);
         return FlinkRemoteBuildPipeline.of(buildRequest);
       case KUBERNETES_NATIVE_SESSION:
@@ -377,11 +333,11 @@ public class AppBuildPipeServiceImpl
                 app.getJobName(),
                 app.getLocalAppHome(),
                 mainClass,
-                flinkUserJar,
+                userLocalJar,
                 app.getExecutionModeEnum(),
                 app.getDevelopmentMode(),
                 flinkEnv.getFlinkVersion(),
-                app.getDependencyInfo(),
+                app.getMavenArtifact(),
                 app.getClusterId(),
                 app.getK8sNamespace());
         log.info("Submit params to building pipeline : {}", k8sSessionBuildRequest);
@@ -392,11 +348,11 @@ public class AppBuildPipeServiceImpl
                 app.getJobName(),
                 app.getLocalAppHome(),
                 mainClass,
-                flinkUserJar,
+                userLocalJar,
                 app.getExecutionModeEnum(),
                 app.getDevelopmentMode(),
                 flinkEnv.getFlinkVersion(),
-                app.getDependencyInfo(),
+                app.getMavenArtifact(),
                 app.getClusterId(),
                 app.getK8sNamespace(),
                 app.getFlinkImage(),
@@ -416,15 +372,139 @@ public class AppBuildPipeServiceImpl
     }
   }
 
+  private void prepareJars(Application app) throws IOException {
+    File localUploadDIR = new File(Workspace.local().APP_UPLOADS());
+    FileUtils.mkdir(localUploadDIR);
+
+    FsOperator localFS = FsOperator.lfs();
+    // 1. copy jar to local upload dir
+    if (app.isFlinkSqlJob() || app.isApacheFlinkCustomCodeJob()) {
+      if (!app.getMavenDependency().getJar().isEmpty()) {
+        for (String jar : app.getMavenDependency().getJar()) {
+          File localJar = new File(WebUtils.getAppTempDir(), jar);
+          File localUploadJar = new File(localUploadDIR, jar);
+          if (!localJar.exists() && !localUploadJar.exists()) {
+            throw new ApiAlertException("Missing file: " + jar + ", please upload again");
+          }
+          if (localJar.exists()) {
+            checkOrElseUploadJar(localFS, localJar, localUploadJar, localUploadDIR);
+          }
+        }
+      }
+    }
+
+    if (app.isApacheFlinkCustomCodeJob()) {
+      // customCode upload jar to appHome...
+      FsOperator fsOperator = app.getFsOperator();
+      ResourceFrom resourceFrom = ResourceFrom.of(app.getResourceFrom());
+
+      File userJar;
+      if (resourceFrom == ResourceFrom.CICD) {
+        userJar = getAppDistJar(app);
+      } else if (resourceFrom == ResourceFrom.UPLOAD) {
+        userJar = new File(WebUtils.getAppTempDir(), app.getJar());
+      } else {
+        throw new IllegalArgumentException("ResourceFrom error: " + resourceFrom);
+      }
+      // 2) copy user jar to localUpload DIR
+      File localUploadJar = new File(localUploadDIR, userJar.getName());
+      checkOrElseUploadJar(localFS, userJar, localUploadJar, localUploadDIR);
+
+      // 3) for YARNApplication mode
+      if (app.getExecutionModeEnum() == ExecutionMode.YARN_APPLICATION) {
+        // 1) upload user jar to hdfs workspace
+        if (!fsOperator.exists(app.getAppHome())) {
+          fsOperator.mkdirs(app.getAppHome());
+        }
+        String pipelineJar = app.getAppHome().concat("/").concat(userJar.getName());
+        if (!fsOperator.exists(pipelineJar)) {
+          fsOperator.upload(localUploadJar.getAbsolutePath(), app.getAppHome());
+        } else {
+          InputStream inputStream = Files.newInputStream(localUploadJar.toPath());
+          if (!DigestUtils.md5Hex(inputStream).equals(fsOperator.fileMd5(pipelineJar))) {
+            fsOperator.upload(localUploadJar.getAbsolutePath(), app.getAppHome());
+          }
+        }
+
+        List<File> dependencyJars = new ArrayList<>(0);
+
+        // 2). jar dependency
+        app.getMavenDependency()
+            .getJar()
+            .forEach(jar -> dependencyJars.add(new File(localUploadDIR, jar)));
+
+        // 3). pom dependency
+        if (!app.getMavenDependency().getPom().isEmpty()) {
+          Set<Artifact> artifacts =
+              app.getMavenDependency().getPom().stream()
+                  .filter(
+                      dep -> {
+                        File file = new File(localUploadDIR, dep.artifactName());
+                        if (file.exists()) {
+                          dependencyJars.add(file);
+                          return false;
+                        }
+                        return true;
+                      })
+                  .map(
+                      pom ->
+                          new Artifact(
+                              pom.getGroupId(),
+                              pom.getArtifactId(),
+                              pom.getVersion(),
+                              pom.getClassifier(),
+                              pom.toExclusionString()))
+                  .collect(Collectors.toSet());
+          Set<File> mavenArts = MavenTool.resolveArtifactsAsJava(artifacts);
+          dependencyJars.addAll(mavenArts);
+        }
+
+        // 4). local uploadDIR to hdfs uploadsDIR
+        String hdfsUploadDIR = Workspace.remote().APP_UPLOADS();
+        for (File jarFile : dependencyJars) {
+          String hdfsUploadPath = hdfsUploadDIR + "/" + jarFile.getName();
+          if (!fsOperator.exists(hdfsUploadPath)) {
+            fsOperator.upload(jarFile.getAbsolutePath(), hdfsUploadDIR);
+          } else {
+            InputStream inputStream = Files.newInputStream(jarFile.toPath());
+            if (!DigestUtils.md5Hex(inputStream).equals(fsOperator.fileMd5(hdfsUploadPath))) {
+              fsOperator.upload(jarFile.getAbsolutePath(), hdfsUploadDIR);
+            }
+          }
+        }
+        // 5). copy jars to $hdfs_app_home/lib
+        if (!fsOperator.exists(app.getAppLib())) {
+          fsOperator.mkdirs(app.getAppLib());
+        } else {
+          fsOperator.mkCleanDirs(app.getAppLib());
+        }
+        dependencyJars.forEach(
+            jar -> fsOperator.copy(hdfsUploadDIR + "/" + jar.getName(), app.getAppLib()));
+      }
+    }
+  }
+
+  private File getAppDistJar(Application app) {
+    if (app.getApplicationType() == ApplicationType.STREAMPARK_FLINK) {
+      return new File(app.getDistHome(), app.getModule().concat(".jar"));
+    }
+    if (app.getApplicationType() == ApplicationType.APACHE_FLINK) {
+      return new File(app.getDistHome(), app.getJar());
+    }
+    throw new IllegalArgumentException(
+        "[StreamPark] unsupported ApplicationType of custom code: " + app.getApplicationType());
+  }
+
   /** copy from {@link ApplicationServiceImpl#start(Application, boolean)} */
-  private String retrieveFlinkUserJar(FlinkEnv flinkEnv, Application app) {
+  private String retrieveUserLocalJar(FlinkEnv flinkEnv, Application app) {
+    File localUploadDIR = new File(Workspace.local().APP_UPLOADS());
     switch (app.getDevelopmentMode()) {
       case CUSTOM_CODE:
         switch (app.getApplicationType()) {
           case STREAMPARK_FLINK:
-            return String.format("%s/%s", app.getAppLib(), app.getModule().concat(".jar"));
+            return String.format("%s/%s", localUploadDIR, app.getModule().concat(".jar"));
           case APACHE_FLINK:
-            return String.format("%s/%s", app.getAppHome(), app.getJar());
+            return String.format("%s/%s", localUploadDIR, app.getJar());
           default:
             throw new IllegalArgumentException(
                 "[StreamPark] unsupported ApplicationType of custom code: "
@@ -432,10 +512,6 @@ public class AppBuildPipeServiceImpl
         }
       case FLINK_SQL:
         String sqlDistJar = commonService.getSqlClientJar(flinkEnv);
-        if (app.getExecutionModeEnum() == ExecutionMode.YARN_APPLICATION) {
-          String clientPath = Workspace.remote().APP_CLIENT();
-          return String.format("%s/%s", clientPath, sqlDistJar);
-        }
         return Workspace.local().APP_CLIENT().concat("/").concat(sqlDistJar);
       default:
         throw new UnsupportedOperationException(
@@ -495,13 +571,13 @@ public class AppBuildPipeServiceImpl
   }
 
   private void checkOrElseUploadJar(
-      FsOperator fsOperator, File localJar, String targetJar, String targetDir) {
-    if (!fsOperator.exists(targetJar)) {
-      fsOperator.upload(localJar.getAbsolutePath(), targetDir, false, true);
+      FsOperator fsOperator, File localJar, File targetJar, File targetDir) {
+    if (!fsOperator.exists(targetJar.getAbsolutePath())) {
+      fsOperator.upload(localJar.getAbsolutePath(), targetDir.getAbsolutePath());
     } else {
       // The file exists to check whether it is consistent, and if it is inconsistent, re-upload it
-      if (!FileUtils.equals(localJar, new File(targetJar))) {
-        fsOperator.upload(localJar.getAbsolutePath(), targetDir, false, true);
+      if (!FileUtils.equals(localJar, targetJar)) {
+        fsOperator.upload(localJar.getAbsolutePath(), targetDir.getAbsolutePath());
       }
     }
   }
