@@ -40,6 +40,7 @@ import org.apache.streampark.console.base.mybatis.pager.MybatisPager;
 import org.apache.streampark.console.base.util.CommonUtils;
 import org.apache.streampark.console.base.util.ObjectUtils;
 import org.apache.streampark.console.base.util.WebUtils;
+import org.apache.streampark.console.core.bean.MavenDependency;
 import org.apache.streampark.console.core.entity.AppBuildPipeline;
 import org.apache.streampark.console.core.entity.Application;
 import org.apache.streampark.console.core.entity.ApplicationConfig;
@@ -703,6 +704,8 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
   public boolean create(Application appParam) {
     ApiAlertException.throwIfNull(
         appParam.getTeamId(), "The teamId can't be null. Create application failed.");
+
+    appParam.setBuild(true);
     appParam.setUserId(commonService.getUserId());
     appParam.setState(FlinkAppState.ADDED.getValue());
     appParam.setRelease(ReleaseState.NEED_RELEASE.get());
@@ -736,6 +739,17 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     }
   }
 
+  @Override
+  public boolean save(Application entity) {
+    String dependency = entity.getDependency();
+    if (entity.isFlinkSqlJob()) {
+      entity.setDependency(null);
+    }
+    boolean flag = super.save(entity);
+    entity.setDependency(dependency);
+    return flag;
+  }
+
   private boolean existsByJobName(String jobName) {
     return this.baseMapper.existsByJobName(jobName);
   }
@@ -797,6 +811,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     newApp.setJarCheckSum(oldApp.getJarCheckSum());
     newApp.setTags(oldApp.getTags());
     newApp.setTeamId(oldApp.getTeamId());
+    newApp.setDependency(oldApp.getDependency());
 
     boolean saved = save(newApp);
     if (saved) {
@@ -836,8 +851,15 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
         String.format(ERROR_APP_QUEUE_HINT, appParam.getYarnQueue(), appParam.getTeamId()));
 
     application.setRelease(ReleaseState.NEED_RELEASE.get());
-    if (application.isUploadJob()) {
-      if (!ObjectUtils.safeEquals(application.getJar(), appParam.getJar())) {
+
+    if (application.isApacheFlinkCustomCodeJob()) {
+      MavenDependency thisDependency = MavenDependency.of(appParam.getDependency());
+      MavenDependency targetDependency = MavenDependency.of(application.getDependency());
+
+      if (!thisDependency.equals(targetDependency)) {
+        application.setDependency(appParam.getDependency());
+        application.setBuild(true);
+      } else if (!ObjectUtils.safeEquals(application.getJar(), appParam.getJar())) {
         application.setBuild(true);
       } else {
         File jarFile = new File(WebUtils.getAppTempDir(), appParam.getJar());
@@ -1465,7 +1487,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
           case STREAMPARK_FLINK:
             flinkUserJar =
                 String.format(
-                    "%s/%s", application.getAppLib(), application.getModule().concat(".jar"));
+                    "%s/%s", application.getAppHome(), application.getModule().concat(".jar"));
             break;
           case APACHE_FLINK:
             flinkUserJar = String.format("%s/%s", application.getAppHome(), application.getJar());
