@@ -79,7 +79,7 @@ export const useCreateAndEditSchema = (
 
   const [registerConfDrawer, { openDrawer: openConfDrawer }] = useDrawer();
 
-  /* 
+  /*
   !The original item is also unassigned
   */
   function getConfigSchemas() {
@@ -119,19 +119,6 @@ export const useCreateAndEditSchema = (
         },
         rules: [{ required: true, message: t('flink.app.addAppTips.flinkSqlIsRequiredMessage') }],
       },
-      {
-        field: 'dependency',
-        label: t('flink.app.dependency'),
-        component: 'Input',
-        slot: 'dependency',
-        ifShow: ({ values }) => {
-          if (edit?.appId) {
-            return values.jobType == JobTypeEnum.SQL;
-          } else {
-            return values?.jobType == 'sql';
-          }
-        },
-      },
       { field: 'configOverride', label: '', component: 'Input', show: false },
       {
         field: 'isSetConfig',
@@ -589,7 +576,13 @@ export const useCreateAndEditSchema = (
       },
     ];
   });
+
   onMounted(async () => {
+    //get flinkEnv
+    fetchFlinkEnv().then((res) => {
+      flinkEnvs.value = res;
+    });
+
     /* Get project data */
     fetchSelect({}).then((res) => {
       projectList.value = res;
@@ -600,10 +593,6 @@ export const useCreateAndEditSchema = (
       alerts.value = res;
     });
 
-    //get flinkEnv
-    fetchFlinkEnv().then((res) => {
-      flinkEnvs.value = res;
-    });
     //get flinkCluster
     fetchFlinkCluster().then((res) => {
       flinkClusters.value = res;
